==> hslua-cli-1.4.3-54-x86_64.pkg.tar.zst: usr/share/haskell/register/hslua-cli.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-cli
version:              1.4.3
visibility:           public
id:                   hslua-cli-1.4.3-GQ4fsPMLBymKlE05x5MVqY
key:                  hslua-cli-1.4.3-GQ4fsPMLBymKlE05x5MVqY
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Command-line interface for Lua
description:
    Provides an embeddable command-line interface for Lua.
    The interface is compatible with the standard Lua
    interpreter, i.e., the `lua` executable provided in a
    default Lua installation.

category:             Foreign
abi:                  dd606ef1afa77551bbf4b0effbf501d9
exposed:              True
exposed-modules:      HsLua.CLI
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hslua-cli
hs-libraries:         HShslua-cli-1.4.3-GQ4fsPMLBymKlE05x5MVqY
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2-7IlE27yFzp5FmDgPxcUzET
    hslua-marshalling-2.3.1-EGEiAdOBx8NJeKRGRBPUUZ
    hslua-repl-0.1.2-JUBkA71u4XN6GeUYwzC57X
    lua-2.3.3-Ea4BE7kc61GjhtVAaItrr text-2.0.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/hslua-cli/html/hslua-cli.haddock
haddock-html:         /usr/share/doc/hslua-cli/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hslua-cli-1.4.3-55-x86_64.pkg.tar.zst: usr/share/haskell/register/hslua-cli.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-cli
version:              1.4.3
visibility:           public
id:                   hslua-cli-1.4.3-DAjYUniBVWBEHt3n0R7eUC
key:                  hslua-cli-1.4.3-DAjYUniBVWBEHt3n0R7eUC
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Command-line interface for Lua
description:
    Provides an embeddable command-line interface for Lua.
    The interface is compatible with the standard Lua
    interpreter, i.e., the `lua` executable provided in a
    default Lua installation.

category:             Foreign
abi:                  6b5811c00376a332e9fd43ff286c2ca1
exposed:              True
exposed-modules:      HsLua.CLI
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hslua-cli
hs-libraries:         HShslua-cli-1.4.3-DAjYUniBVWBEHt3n0R7eUC
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2-CioTfMG9Ml2Lkmjmm7zI9U
    hslua-marshalling-2.3.1-C0K1WOE0GsN7XQHCGiWLQP
    hslua-repl-0.1.2-FPc2X3jAXx71F0YYpGe24S
    lua-2.3.3-Hl6t7b5iy8qpyU75C96gB text-2.0.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/hslua-cli/html/hslua-cli.haddock
haddock-html:         /usr/share/doc/hslua-cli/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
